==> Stimulsoft-Ultimate-2025.4.3.zip: Ultimate/Angular/stimulsoft-forms/lib/services/sti-helper.service.d.ts <==
import { NgZone } from "@angular/core";
import { MenuItem } from "primeng/api";
import StiRectangleGeometryLayout from "../computed/StiRectangleGeometryLayout";
import { StiFormElement } from "../elements/base/StiFormElement";
import { StiFormPageElement } from "../elements/StiFormPageElement";
import { StiModelService } from "./model.service";
import { Item } from "./objects";
import { StiLocalizationService } from "./sti-localization.service";
import * as i0 from "@angular/core";
export declare class StiHelperService {
    model: StiModelService;
    render: StiRectangleGeometryLayout;
    loc: StiLocalizationService;
    private zone;
    addTotalMenuItems: MenuItem[];
    private _fonts;
    private _numberTypes;
    private _rangeFormats;
    private _signatureTypes;
    private _dateTimeTypes;
    private _buttonTypes;
    private _columnTypes;
    private _buttonSendTypes;
    private _thousandSeparators;
    private _barcodeTypes;
    private _dateTimeValues;
    private _themes;
    private _borderWeights;
    private _unitAlignment;
    private _minUnitAlignment;
    private _labelFormat;
    private _penStyles;
    private _algorithmExpressions;
    private _dateTimeFormats;
    private _dateFormats;
    private _timeFormats;
    private _cultures;
    private _signatureEditorModes;
    private _signatureSpecialFonts;
    private _fontSizes;
    private _richTextFontSizes;
    private _errorCorrectionLevel;
    private _fileMenuItems;
    private _dataMatrixSize;
    private _bodyShapeType;
    private _eyeFrameShapeType;
    private _eyeBallShapeType;
    private _brushIdent;
    private _bodyBrush;
    hatchStyle: any[];
    getProperty(element: any, prop: string): any;
    setProperty(element: any, prop: string, value: any): void;
    justifyOptions: any[];
    labelAlignment: any[];
    verticalAlignment: any[];
    styleOptions: any[];
    constructor(model: StiModelService, render: StiRectangleGeometryLayout, loc: StiLocalizationService, zone: NgZone);
    countries: any[];
    currencyInfo: any[];
    get richTextFontSizes(): Item[];
    get fontSizes(): number[];
    elementTypes: {
        AddressElement: string;
        Text_BoxElement: string;
        TextElement: string;
        TableElement: string;
        Single_SelectionElement: string;
        SignatureElement: string;
        PDFSignatureElement: string;
        PanelElement: string;
        Number_BoxElement: string;
        Multiple_SelectionElement: string;
        List_BoxElement: string;
        LabelElement: string;
        ImageElement: string;
        LineElement: string;
        DateTime_BoxElement: string;
        Combo_BoxElement: string;
        Check_BoxElement: string;
        ButtonElement: string;
        BarCodeElement: string;
        StiPageElement: string;
    };
    elementCategories: {
        AddressElement: string;
        Text_BoxElement: string;
        LineElement: string;
        DateTime_BoxElement: string;
        LabelElement: string;
    };
    getLocalizationKey(type: any): any;
    getLocalizationCategory(type: any): any;
    get errorCorrectionLevel(): string[];
    get bodyShapeType(): string[];
    get eyeFrameShapeType(): string[];
    get eyeBallShapeType(): string[];
    get brushIdent(): string[];
    get bodyBrush(): string[];
    get dataMatrixSize(): string[];
    get numberTypes(): Item[];
    get rangeFormats(): Item[];
    get signatureTypes(): Item[];
    get columnTypes(): Item[];
    get buttonTypes(): Item[];
    get algorithmExpressions(): Item[];
    get buttonSendTypes(): Item[];
    get barcodeTypes(): Item[];
    get dateTimeTypes(): Item[];
    get penStyles(): Item[];
    get dateTimeFormats(): Item[];
    get dateFormats(): Item[];
    get timeFormats(): Item[];
    get signatureEditorModes(): Item[];
    get signatureSpecialFonts(): Item[];
    get dateTimeValues(): Item[];
    get themes(): Item[];
    get borderWeights(): Item[];
    get unitAlignment(): Item[];
    get minUnitAlignment(): Item[];
    get labelFormat(): Item[];
    get thousandSeparators(): Item[];
    updateHelper(): void;
    deleteSelectedComponent(): void;
    getElementClass(type: string): any;
    clone(element: StiFormElement): StiFormElement;
    clonePage(page: StiFormPageElement): StiFormPageElement;
    get fileMenuItems(): any[];
    getAddTotalMenuItems(): MenuItem[];
    _keyStr: "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
    base64Encode(input: any): string;
    base64Decode(input: any): string;
    get cultures(): any[];
    static ɵfac: i0.ɵɵFactoryDeclaration<StiHelperService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<StiHelperService>;
}

==> Stimulsoft-Ultimate-2026.1.4.zip: Ultimate/Angular/stimulsoft-forms/lib/services/sti-helper.service.d.ts <==
import { NgZone } from "@angular/core";
import StiRectangleGeometryLayout from "../computed/StiRectangleGeometryLayout";
import { StiFormElement } from "../elements/base/StiFormElement";
import { StiFormPageElement } from "../elements/StiFormPageElement";
import { StiModelService } from "./model.service";
import { Item, MenuItem } from "./objects";
import { StiLocalizationService } from "./sti-localization.service";
import * as i0 from "@angular/core";
export declare class StiHelperService {
    model: StiModelService;
    render: StiRectangleGeometryLayout;
    loc: StiLocalizationService;
    private zone;
    addTotalMenuItems: MenuItem[];
    private _fonts;
    private _numberTypes;
    private _rangeFormats;
    private _signatureTypes;
    private _dateTimeTypes;
    private _buttonTypes;
    private _columnTypes;
    private _buttonSendTypes;
    private _thousandSeparators;
    private _barcodeTypes;
    private _dateTimeValues;
    private _themes;
    private _borderWeights;
    private _unitAlignment;
    private _minUnitAlignment;
    private _labelFormat;
    private _penStyles;
    private _algorithmExpressions;
    private _dateTimeFormats;
    private _dateFormats;
    private _timeFormats;
    private _cultures;
    private _signatureEditorModes;
    private _signatureSpecialFonts;
    private _fontSizes;
    private _richTextFontSizes;
    private _errorCorrectionLevel;
    private _fileMenuItems;
    private _dataMatrixSize;
    private _bodyShapeType;
    private _eyeFrameShapeType;
    private _eyeBallShapeType;
    private _brushIdent;
    private _bodyBrush;
    hatchStyle: any[];
    getProperty(element: any, prop: string): any;
    setProperty(element: any, prop: string, value: any): void;
    justifyOptions: any[];
    labelAlignment: any[];
    verticalAlignment: any[];
    styleOptions: any[];
    constructor(model: StiModelService, render: StiRectangleGeometryLayout, loc: StiLocalizationService, zone: NgZone);
    countries: any[];
    currencyInfo: any[];
    get richTextFontSizes(): Item[];
    get fontSizes(): number[];
    elementTypes: {
        AddressElement: string;
        Text_BoxElement: string;
        TextElement: string;
        TableElement: string;
        Single_SelectionElement: string;
        SignatureElement: string;
        PDFSignatureElement: string;
        PanelElement: string;
        Number_BoxElement: string;
        Multiple_SelectionElement: string;
        List_BoxElement: string;
        LabelElement: string;
        ImageElement: string;
        LineElement: string;
        DateTime_BoxElement: string;
        Combo_BoxElement: string;
        Check_BoxElement: string;
        ButtonElement: string;
        BarCodeElement: string;
        StiPageElement: string;
    };
    elementCategories: {
        AddressElement: string;
        Text_BoxElement: string;
        LineElement: string;
        DateTime_BoxElement: string;
        LabelElement: string;
    };
    getLocalizationKey(type: any): any;
    getLocalizationCategory(type: any): any;
    get errorCorrectionLevel(): string[];
    get bodyShapeType(): string[];
    get eyeFrameShapeType(): string[];
    get eyeBallShapeType(): string[];
    get brushIdent(): string[];
    get bodyBrush(): string[];
    get dataMatrixSize(): string[];
    get numberTypes(): Item[];
    get rangeFormats(): Item[];
    get signatureTypes(): Item[];
    get columnTypes(): Item[];
    get buttonTypes(): Item[];
    get algorithmExpressions(): Item[];
    get buttonSendTypes(): Item[];
    get barcodeTypes(): Item[];
    get dateTimeTypes(): Item[];
    get penStyles(): Item[];
    get dateTimeFormats(): Item[];
    get dateFormats(): Item[];
    get timeFormats(): Item[];
    get signatureEditorModes(): Item[];
    get signatureSpecialFonts(): Item[];
    get dateTimeValues(): Item[];
    get themes(): Item[];
    get borderWeights(): Item[];
    get unitAlignment(): Item[];
    get minUnitAlignment(): Item[];
    get labelFormat(): Item[];
    get thousandSeparators(): Item[];
    updateHelper(): void;
    deleteSelectedComponent(): void;
    getElementClass(type: string): any;
    clone(element: StiFormElement): StiFormElement;
    clonePage(page: StiFormPageElement): StiFormPageElement;
    get fileMenuItems(): any[];
    getAddTotalMenuItems(): MenuItem[];
    _keyStr: "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
    base64Encode(input: any): string;
    base64Decode(input: any): string;
    get cultures(): any[];
    static ɵfac: i0.ɵɵFactoryDeclaration<StiHelperService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<StiHelperService>;
}
